@@ -176,7 +176,7 @@ sub do_foreach_opt_combination {
         my $context_msg = "NYTPROF=$ENV{NYTPROF}\n";
         ($opts{v}) ? warn $context_msg : print $context_msg;
 
-        ok eval { $code->(\%env) };
+        ok eval { $code->(\%env) }, "combination eval-ed okay";
         if ($@) {
             diag "Test group aborted: $@";
             last COMBINATION;
@@ -541,7 +541,7 @@ sub dump_profile_to_file {
             separator  => "\t",
             skip_fileinfo_hook => sub {
                 my $fi = shift;
-                return 1 if $fi->filename =~ /(AutoLoader|Exporter)\.pm$/ or $fi->filename =~ m!^/\.\.\./!;
+                return 1 if $fi->filename =~ /(AutoLoader|Exporter|strict)\.pm$/ or $fi->filename =~ m!^/\.\.\./!;
                 return 0;
             },
         }
